# -*- coding: utf-8 -*-
# Generated by Django 1.11.7 on 2018-05-27 11:15
from __future__ import unicode_literals

from django.db import migrations, models


class Migration(migrations.Migration):

    initial = True

    dependencies = [
    ]

    operations = [
        migrations.CreateModel(
            name='Rate',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('currency', models.CharField(max_length=3, unique=True)),
                ('value', models.DecimalField(decimal_places=6, max_digits=20)),
                ('updated', models.DateField(auto_now=True)),
            ],
            options={
                'ordering': ('currency',),
            },
        ),
    ]
